#ifdef FF_HAVE_WAYLAND

/* Generated by wayland-scanner 1.22.0 */

/*
 * SPDX-FileCopyrightText: 2022 Xaver Hugl <xaver.hugl@gmail.com>
 *
 * SPDX-License-Identifier: MIT-CMU
 */

    #include <stdlib.h>
    #include <stdint.h>
    #include "wayland-util.h"

static const struct wl_interface* kde_output_order_v1_types[] = {
    NULL,
};

static const struct wl_message kde_output_order_v1_requests[] = {
    { "destroy", "", kde_output_order_v1_types + 0 },
};

static const struct wl_message kde_output_order_v1_events[] = {
    { "output", "s", kde_output_order_v1_types + 0 },
    { "done", "", kde_output_order_v1_types + 0 },
};

WL_EXPORT const struct wl_interface kde_output_order_v1_interface = {
    "kde_output_order_v1",
    1,
    1,
    kde_output_order_v1_requests,
    2,
    kde_output_order_v1_events,
};

#endif
